foxygit / doom Log in
commit 4a70f989d2aacabffc2f02017704de042be7418a
Author:     Simon Howard <fraggle@gmail.com>
AuthorDate: Thu Oct 1 00:08:48 2009 +0000
Commit:     Simon Howard <fraggle@gmail.com>
CommitDate: Thu Oct 1 00:08:48 2009 +0000

    Convert to American English spellings.

    Subversion-branch: /branches/opl-branch
    Subversion-revision: 1700
---
 opl/opl.c        |  4 ++--
 opl/opl_sdl.c    | 18 +++++++++---------
 src/i_oplmusic.c | 30 +++++++++++++++---------------
 3 files changed, 26 insertions(+), 26 deletions(-)

diff --git a/opl/opl.c b/opl/opl.c
index 749c19d1..bf999d47 100644
--- a/opl/opl.c
+++ b/opl/opl.c
@@ -236,9 +236,9 @@ void OPL_WriteRegister(int reg, int value)

     for (i=0; i<6; ++i)
     {
-        // An oddity of the Doom OPL code: at startup initialisation,
+        // An oddity of the Doom OPL code: at startup initialization,
         // the spacing here is performed by reading from the register
-        // port; after initialisation, the data port is read, instead.
+        // port; after initialization, the data port is read, instead.

         if (init_stage_reg_writes)
         {
diff --git a/src/i_oplmusic.c b/src/i_oplmusic.c
index e9e722e4..35ba046d 100644
--- a/src/i_oplmusic.c
+++ b/src/i_oplmusic.c
@@ -303,7 +303,7 @@ static const unsigned int volume_mapping_table[] = {
     124, 124, 125, 125, 126, 126, 127, 127
 };

-static boolean music_initialised = false;
+static boolean music_initialized = false;

 //static boolean musicpaused = false;
 static int current_music_volume;
@@ -546,7 +546,7 @@ static void SetVoiceVolume(opl_voice_t *voice, unsigned int volume)
     }
 }

-// Initialise the voice table and freelist
+// Initialize the voice table and freelist

 static void InitVoices(void)
 {
@@ -556,7 +556,7 @@ static void InitVoices(void)

     voice_free_list = NULL;

-    // Initialise each voice.
+    // Initialize each voice.

     for (i=0; i<OPL_NUM_VOICES; ++i)
     {
@@ -575,7 +575,7 @@ static void InitVoices(void)

 static void I_OPL_ShutdownMusic(void)
 {
-    if (music_initialised)
+    if (music_initialized)
     {
         OPL_Shutdown();

@@ -583,11 +583,11 @@ static void I_OPL_ShutdownMusic(void)

         W_ReleaseLumpName("GENMIDI");

-        music_initialised = false;
+        music_initialized = false;
     }
 }

-// Initialise music subsystem
+// Initialize music subsystem

 static boolean I_OPL_InitMusic(void)
 {
@@ -607,7 +607,7 @@ static boolean I_OPL_InitMusic(void)

     InitVoices();

-    music_initialised = true;
+    music_initialized = true;

     return true;
 }
@@ -1142,7 +1142,7 @@ static void ScheduleTrack(opl_track_data_t *track)
     OPL_SetCallback(ms, TrackTimerCallback, track);
 }

-// Initialise a channel.
+// Initialize a channel.

 static void InitChannel(opl_track_data_t *track, opl_channel_data_t *channel)
 {
@@ -1186,7 +1186,7 @@ static void I_OPL_PlaySong(void *handle, int looping)
     midi_file_t *file;
     unsigned int i;

-    if (!music_initialised || handle == NULL)
+    if (!music_initialized || handle == NULL)
     {
         return;
     }
@@ -1211,7 +1211,7 @@ static void I_OPL_PauseSong(void)
 {
     unsigned int i;

-    if (!music_initialised)
+    if (!music_initialized)
     {
         return;
     }
@@ -1235,7 +1235,7 @@ static void I_OPL_PauseSong(void)

 static void I_OPL_ResumeSong(void)
 {
-    if (!music_initialised)
+    if (!music_initialized)
     {
         return;
     }
@@ -1247,7 +1247,7 @@ static void I_OPL_StopSong(void)
 {
     unsigned int i;

-    if (!music_initialised)
+    if (!music_initialized)
     {
         return;
     }
@@ -1279,7 +1279,7 @@ static void I_OPL_StopSong(void)

 static void I_OPL_UnRegisterSong(void *handle)
 {
-    if (!music_initialised)
+    if (!music_initialized)
     {
         return;
     }
@@ -1328,7 +1328,7 @@ static void *I_OPL_RegisterSong(void *data, int len)
     midi_file_t *result;
     char *filename;

-    if (!music_initialised)
+    if (!music_initialized)
     {
         return NULL;
     }
@@ -1368,7 +1368,7 @@ static void *I_OPL_RegisterSong(void *data, int len)
 // Is the song playing?
 static boolean I_OPL_MusicIsPlaying(void)
 {
-    if (!music_initialised)
+    if (!music_initialized)
     {
         return false;
     }
diff --git a/opl/opl_sdl.c b/opl/opl_sdl.c
index e38f9f6e..40430546 100644
--- a/opl/opl_sdl.c
+++ b/opl/opl_sdl.c
@@ -79,11 +79,11 @@ static int16_t *mix_buffer = NULL;

 // SDL parameters.

-static int sdl_was_initialised = 0;
+static int sdl_was_initialized = 0;
 static int mixing_freq, mixing_channels;
 static Uint16 mixing_format;

-static int SDLIsInitialised(void)
+static int SDLIsInitialized(void)
 {
     int freq, channels;
     Uint16 format;
@@ -227,13 +227,13 @@ static void OPL_SDL_Shutdown(void)
 {
     Mix_SetPostMix(NULL, NULL);

-    if (sdl_was_initialised)
+    if (sdl_was_initialized)
     {
         Mix_CloseAudio();
         SDL_QuitSubSystem(SDL_INIT_AUDIO);
         OPL_Queue_Destroy(callback_queue);
         free(mix_buffer);
-        sdl_was_initialised = 0;
+        sdl_was_initialized = 0;
     }

     if (opl_emulator != NULL)
@@ -281,9 +281,9 @@ static void TimerHandler(int channel, double interval_seconds)
 static int OPL_SDL_Init(unsigned int port_base)
 {
     // Check if SDL_mixer has been opened already
     // If not, we must initialise it now

-    if (!SDLIsInitialised())
+    if (!SDLIsInitialized())
     {
         if (SDL_Init(SDL_INIT_AUDIO) < 0)
         {
@@ -304,11 +304,11 @@ static int OPL_SDL_Init(unsigned int port_base)
         // When this module shuts down, it has the responsibility to
         // shut down SDL.

-        sdl_was_initialised = 1;
+        sdl_was_initialized = 1;
     }
     else
     {
-        sdl_was_initialised = 0;
+        sdl_was_initialized = 0;
     }

     opl_sdl_paused = 0;
@@ -345,7 +345,7 @@ static int OPL_SDL_Init(unsigned int port_base)

     if (opl_emulator == NULL)
     {
-        fprintf(stderr, "Failed to initialise software OPL emulator!\n");
+        fprintf(stderr, "Failed to initialize software OPL emulator!\n");
         OPL_SDL_Shutdown();
         return 0;
     }
@@ -281,9 +281,9 @@ static void TimerHandler(int channel, double interval_seconds)
 {
     // Check if SDL_mixer has been opened already
-    // If not, we must initialise it now
+    // If not, we must initialize it now
